import React, {PureComponent} from "react";
import {connect} from "react-redux";
import axios from "axios";
import {SearchWrapper, MainWrapper} from './style';
import CatList from "../../components/List";
import PagInation from '../../components/PagInation';

class Search extends PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            key: props.match.params.key,
            finished: false,
            loading: true,
            current: 1,
            list: []
        };
        this.getList = this.getList.bind(this);
    }

    render() {
        const {list, current, finished, loading, key} = this.state;
        return (
            <SearchWrapper>
                <div className='pattern-center-blank'/>
                <MainWrapper>
                    <header className="page-header">
                        <h1 className="page-title">{`搜索结果：${key}`}</h1>
                    </header>
                    <CatList list={list}/>
                    <PagInation page={current} id={key} finished={finished} loading={loading} getList={this.getList}/>
                </MainWrapper>
            </SearchWrapper>
        )
    }

    componentDidMount() {
        this.getList(1, this.state.key, true);
    }

    getList(current, key, override) {
        this.setState({loading: true});
        axios.get('/api/v1/post/list', {
            params: {
                current: current,
                size: 10,
                keyword: key
            }
        }).then((res) => {
            if (res.code === 0) {
                let total = res.data.total;
                const Img = this.props.ListImg;
                let arr = [];

                const {records = []} = res.data;
                if (records == null) {
                    this.setState({
                        finished: true
                    })
                    return
                }

                records.forEach((item) => {
                    arr.push({
                        id: item.id,
                        title: item.title,
                        thumbnail: item.thumbnail || Img[this.getrand(0, Img.length - 1)].img,
                        comments: item.comments,
                        status: item.status,
                        summary: item.summary,
                        views: item.views,
                        createTime: item.createTime,
                        syncStatus: item.syncStatus,
                        author: item.author,
                        categoryName: item.categoryName
                    })
                });

                this.setState((prevState) => {
                    return {
                        list: override ? arr : [...prevState.list, ...arr],
                        current: current + 1,
                        loading: false
                    }
                });

                if ((res.data.current * res.data.size) > total) {
                    this.setState({
                        finished: true
                    })
                }
            }
        });
    }

    getrand(m, n) {
        return Math.floor(Math.random() * (n - m + 1)) + m;
    };
}

const mapState = (state) => {
    return {
        ListImg: state.getIn(['image', 'ListImg'])
    }
};

export default connect(mapState)(Search)
